@@ -6,7 +6,8 @@ use warnings;
 use strict;
 
 package XML::Compile::SOAP::Client;
-our $VERSION = '3.04';
+use vars '$VERSION';
+$VERSION = '3.05';
 
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
@@ -19,6 +20,7 @@ use Time::HiRes        qw/time/;
 sub new(@) { panic __PACKAGE__." only secundary in multiple inheritance" }
 sub init($) { shift }
 
+#--------------
 
 my $rr = 'request-response';
 
@@ -51,7 +53,7 @@ sub compileClient(@)
     }
 
     my $output_handler = sub {
-        my ($ans, $trace) = @_;
+        my ($ans, $trace, $xops) = @_;
         wantarray or return
             UNIVERSAL::isa($ans, 'XML::LibXML::Node') ? $decode->($ans) : $ans;
 
@@ -72,7 +74,7 @@ sub compileClient(@)
         {   $trace->{elapse} = $trace->{transport_end} - $trace->{start}
                 if defined $trace->{transport_end};
         }
-        ($ans, XML::Compile::SOAP::Trace->new($trace));
+        ($ans, XML::Compile::SOAP::Trace->new($trace), $xops);
     };
 
     $args{async}
@@ -84,7 +86,7 @@ sub compileClient(@)
               , name => $name;
 
         my $callback = delete $data->{_callback}
-            or error __x"opertaion `{name}' is async, so requires _callback";
+            or error __x"operation `{name}' is async, so requires _callback";
 
         my $trace = {start => time};
         my ($req, $mtom) = $encode->($data, $charset);
@@ -107,10 +109,12 @@ sub compileClient(@)
 
         my $trace = {start => time};
         my ($req, $mtom) = $encode->($data, $charset);
-        my $ans = $transport->($req, $trace, $mtom);
+        my ($ans, $xops) = $transport->($req, $trace, $mtom);
+        wantarray || !$xops || ! keys %$xops
+            or warning "loosing received XOPs";
 
         $trace->{encode_elapse} = $trace->{transport_start} - $trace->{start};
-        $output_handler->($ans, $trace);
+        $output_handler->($ans, $trace, $xops);
       };
 }
 
